
global dir "/Users/bingjingli/Dropbox/China_export_environment/replication package"
clear all
discard
set seed 12345
use "$dir/Rotemberg/Rotemberg_China.dta", clear

egen temp=rowtotal(sh_ind_*)
drop if temp==0
drop temp /* dropping prefectures with no manufacturing sector */
drop if lag_d_All_mortality==.

gen province=substr(prefect_adj,1,2)
gen t2=cond(year==2010,1,0)
tab region_year, gen(region_year_)
tab year_dist_g, gen(year_dist_)

local controls lag_GDP_cap lag_All_mortality_overall lag_share_agriculture lag_pop_density ///
d_highschool d_midschool d_sex_ratio d_Beds_pop d_share_agriculture capital ///
lag_d_All_mortality lag_d_All_mortality2 region_year_3-region_year_16

local controls_a `controls' shock_pt_f_chn 
local controls_b `controls' DD_f_chn 

local weight weight

local y d_All_mortality
local x_a DD_chn
local z_a DD_f_chn
local x_b shock_pt_chn /* changes to this line to calculate Rotemberg index for pollution export shocks */
local z_b shock_pt_f_chn

local ind_stub sh_ind_
local growth_stub_a export_shock_
local growth_stub_b trade_shock_pt_

local time_var year
local cluster_var prefect_adj

levelsof `time_var', local(years)
foreach year in `years' {
	foreach ind_var of varlist `ind_stub'* {
		gen t`year'_`ind_var' = `ind_var' * (year == `year')*100
		}
	}

/* Demeaning Growth Rates */
egen mean_growth = rowmean(`growth_stub_a'*)
foreach growth of varlist `growth_stub_a'* {
	replace `growth' = `growth' - mean_growth
	}
drop mean_growth

egen mean_growth = rowmean(`growth_stub_b'*)
foreach growth of varlist `growth_stub_b'* {
	replace `growth' = `growth' - mean_growth
	}
drop mean_growth

/*
forvalues t = 2000(10)2010 {
	forvalues k = 20(1)39 {
		egen agg_sh_ind_`k'_`t' = rowtotal(t`t'_sh_ind_`k'*)
		}
	}
*/	
		
bartik_weight, z(t*_`ind_stub'*)    weightstub(`growth_stub_a'*) x(`x_a') y(`y') controls(`controls_a'   ) weight_var(`weight') absorb(year_dist_g) by(year)
/*!!! changes to this line to calculate Rotemberg index for pollution export shocks */
*bartik_weight, z(t*_`ind_stub'*)    weightstub(`growth_stub_b'*) x(`x_b') y(`y')  controls(`controls_b'   ) weight_var(`weight') absorb(year_dist_g) by(year) 

mat beta = r(beta)
mat alpha = r(alpha)
mat G = r(G)
qui desc t*_`ind_stub'*, varlist
local varlist = r(varlist)


clear
svmat beta
svmat alpha
svmat G

gen ind = ""
gen year = ""
local t = 1
foreach var in `varlist' {
	if regexm("`var'", "t(.*)_`ind_stub'(.*)") {
		qui replace year = regexs(1) if _n == `t'
		qui replace ind = regexs(2) if _n == `t'
		}
	local t = `t' + 1
	}
	
bysort ind: egen temp=sum(alpha1)
replace beta1=beta1*alpha1/temp
egen sum_alpha_pos=sum(alpha1) if alpha1>0
	
collapse (sum) alpha1 (sum) beta1 (mean) sum_alpha_pos, by(ind)	

/* identify the industries with the largest rotemberg weights */
gsort - alpha1
	
/* 	Top five Rotemberg weights as a share of positive weight */
gen cum_weight=sum(alpha1)
replace cum_weight=cum_weight/sum_alpha_pos
	
