
* Event Study of the 2001-03 steel safeguard measures */

*****************************
*use "..../SG_data.dta"

gen after=0
replace after=1 if ymd>20031204 /*date that US lifted SG*/
gen before=0
replace before=1 if ymd<20010628 /*date that US initiated the investigation*/
gen no_SG=0
replace no_SG=1 if ymd>20031204|ymd<20010628

/* Diff-in-Diff */

* different time windows
areg API c.before#c.share i.year#i.region i.month#i.region if ym>=200007 & ym<=200209, absorb(prefect_adj) cluster(prefect_adj)
est store r1
areg API c.before#c.share i.year#i.region i.month#i.region if ym>=200007 & ym<=200212, absorb(prefect_adj) cluster(prefect_adj)
est store r2
areg API c.after#c.share i.year#i.region i.month#i.region if ym>=200206 & ym<=200505, absorb(prefect_adj) cluster(prefect_adj)
est store r3
areg API c.after#c.share i.year#i.region i.month#i.region if ym>=200203 & ym<=200508, absorb(prefect_adj) cluster(prefect_adj)
est store r4
areg API c.no_SG#c.share i.year#i.region i.month#i.region if ym>=200007 & ym<=200505, absorb(prefect_adj) cluster(prefect_adj)
est store r5
areg API c.no_SG#c.share i.year#i.region i.month#i.region if ym>=200007 & ym<=200508, absorb(prefect_adj) cluster(prefect_adj)
est store r6

outreg2 [r1 r2 r3 r4 r5 r6] using ".../Reports/result.tex", keep(c.before#c.share c.after#c.share c.no_SG#c.share) dec(3) tex replace


*****************************
/* quarterly impacts */

/* generate dummies for different quarters before and after safeguard */
egen temp=group(ym)

tab temp if ym==200312
gen q0=0
replace q0=1 if temp==40|temp==41|temp==42
forvalues q=1(1)3 {
	gen q`q'=0
	replace q`q'=1 if temp==42+3*`q'|temp==42+3*`q'-1|temp==42+3*`q'-2
	gen q_`q'=0
	replace q_`q'=1 if temp==40-3*`q'|temp==40-3*`q'+1|temp==40-3*`q'+2
	}
	
global event1=""
foreach var of varlist q_3 q_2 q_1 q0 q1 q2 q3  {
	global event1="$event1 c.`var'#c.share"
	}
	
tab temp if ym==200106
gen q_b0=0
replace q_b0=1 if temp==14|temp==15|temp==16
forvalues q=1(1)3 {
	gen q_b`q'=0
	replace q_b`q'=1 if temp==16+3*`q'|temp==16+3*`q'-1|temp==16+3*`q'-2
	gen q_b_`q'=0
	replace q_b_`q'=1 if temp==14-3*`q'|temp==14-3*`q'+1|temp==14-3*`q'+2
	}
global event2=""
foreach var of varlist q_b_3 q_b_2 q_b_1 q_b0 q_b1 q_b2 q_b3 {
	global event2="$event2 c.`var'#c.share"
	}


/* regression and figure */	
set matsize 5000
areg API $event2 $event1 i.year#i.region i.month#i.region if ym>=200010 & ym<=200408, absorb(prefect_adj) cluster(prefect_adj)	

matrix temp=J(15,2,0)
local temp_var "$event2 $event1"
local counter=1
foreach var of local temp_var {
	matrix temp[`counter',1]=_b[`var']
	matrix temp[`counter',2]=_se[`var']
	if `counter'==7 {
		local counter=`counter'+2
		}
	else {
		local counter=`counter'+1
		}
	}

preserve

svmat temp, names(temp)
keep temp1 temp2
keep in 1/15
rename temp1 estimate
rename temp2 se
cap drop estimate_u estimate_l
gen estimate_u=estimate+1.645*se
gen estimate_l=estimate-1.645*se
gen temp=_n

twoway (connected estimate temp, lcolor(blue) mcolor(blue) msize(1))  ///
(line estimate_u temp, lcolor(blue) lpattern(dash) lwidth(thin)) ///
(line estimate_l temp, lcolor(blue) lpattern(dash) lwidth(thin)), /// 
xline(4, lwidth(0.3)) xline(12, lwidth(0.3)) ylabel(-4(2)8) /// 
text(8 1.8 "Before", place(e) size(3)) text(8 12 " After", place(e) size(3)) ///
xlabel(1 "10/00-12/00" 2 "01/01-03/01" 3 "04/01-06/01" ///
4 "07/01-09/01" 5 "10/01-12/01" 6 "01/02-03/02" 7 "04/02-06/02" ///
8 "07/02-11/02" 9 "12/02-02/03" 10 "03/03-05/03" 11 "06/03-08/03" 12 "09/03-11/03" ///
13 "12/03-02/04" 14 "03/04-05/04" 15 "06/04-08/04", labsize(3) angle(45)) ///
xtitle("Time") ytitle("Effect of SG on API", size(3)) legend(off) graphregion(color(white))

*graph export ".../Estimates_q.eps",replace

restore












