
clear
global dir "/Users/bingjingli/Dropbox/China_export_environment/replication package"

use "$dir/workfile.dta",clear

******************

global controls_a "lag_GDP_cap lag_All_mortality_overall lag_share_agriculture lag_pop_density capital"
global controls_b "d_highschool d_midschool d_sex_ratio d_Beds_pop d_share_agriculture dist_g"
global controls_d "lag_d_All_mortality lag_d_All_mortality2"
global controls_e "lag_share_emp_ind_l lag_share_emp_ind_m lag_share_emp_ind_h"
global controls_f "i.year#c.lag_SO2"
global pollutant "so2 pt no2 pca"

set matsize 5000

egen region_year=group(region year)
egen province_year=group(province year)
destring prefect_adj, replace 

sort prefect_adj age_group year
bysort prefect_adj age_group: gen lag_emp_agri=emp_agri[_n-1]
gen s_trade_emp=s_agri_emp+s_sec_emp
bysort prefect_adj age_group: gen lag_s_trade_emp=s_trade_emp[_n-1]

keep if year>=2000 & age_group==1
drop if province==54 & year==2000
cap drop poll_emp_pca_chn
pca poll_emp_pt_chn poll_emp_so2_chn poll_emp_pt_chn
predict poll_emp_pca_chn

xtile lag_s_agri_pop_g3=lag_s_agri_pop, nq(3)
xtile lag_s_agri_pop_g5=lag_s_agri_pop, nq(5)
xtile lag_share_emp_trade_g5=lag_share_emp_trade, nq(5)

foreach var of varlist shock_pt_chn shock_so2_chn shock_no2_chn shock_pt_f_chn shock_so2_f_chn shock_no2_f_chn ///
	DD_chn DD_f_chn poll_emp_so2_chn poll_emp_pt_chn poll_emp_no2_chn {
	gen `var'_r=`var'/lag_share_emp_trade
	}
pca shock_pt_chn_r shock_so2_chn_r shock_no2_chn_r
predict shock_pca_chn_r
pca shock_pt_f_chn_r shock_so2_f_chn_r shock_no2_f_chn_r
predict shock_pca_f_chn_r
pca poll_emp_so2_chn_r poll_emp_pt_chn_r poll_emp_no2_chn_r
predict poll_emp_pca_chn_r


****************
** Table A.11 **

ivreghdfe d_All_mortality $controls_a $controls_b $controls_d poll_emp_pca_chn i.lag_s_agri_pop_g5 (shock_pca_chn DD_chn=shock_pca_f_chn DD_f_chn) if age_group==1 [aweight=weight], absorb(i.region_year) cluster(province)
est store r1
ivreghdfe d_All_mortality $controls_a $controls_b $controls_d poll_emp_pca_chn_r i.lag_share_emp_trade_g5 (shock_pca_chn DD_chn=shock_pca_f_chn DD_f_chn) if age_group==1 [aweight=weight], absorb(region_year) cluster(province)
est store r2
ivreghdfe d_All_mortality $controls_a $controls_b $controls_d poll_emp_pca_chn_r (shock_pca_chn_r DD_chn_r=shock_pca_f_chn_r DD_f_chn_r) if age_group==1 [aweight=weight], absorb(region_year) cluster(province)
est store r3
ivreghdfe d_All_mortality shock_FDIbtk_pca d_FDIbtk $controls_a $controls_b $controls_d poll_emp_pca_chn (shock_pca_chn DD_chn=shock_pca_f_chn DD_f_chn) if age_group==1 & year==2010 [aweight=weight], absorb(i.region_year) cluster(province)
est store r4
outreg2 [r1 r2 r3 r4] using "$dir/result/result_robust_additional.tex", keep(shock_pca_chn DD_chn c.poll_emp_pca_chn#c.DD_chn shock_pca_chn_r DD_chn_r shock_FDIbtk_pca d_FDIbtk) dec(3) tex replace


****************
** Table A.13 **

** second stage
ivreg2 d_All_mortality (shock_pca_chn DD_chn=shock_pca_f_chn DD_f_chn) $controls_a $controls_b $controls_d i.region_year poll_emp_pca_chn if age_group==1 & year==2010 [aweight=weight], endog(shock_pca_chn DD_chn) first ffirst savefirst partial(i.region_year) cluster(province)
matrix stat=e(first)
local temp1=stat[15,1]
local temp2=stat[15,2]
outreg2 using "$dir/result/result_age0_ntr.tex", keep(shock_pca_chn DD_chn) dec(3) addstat("Fstat PollExpShock", `temp1', "Fstat ExpShock", `temp2') tex nocons replace

ivreg2 d_All_mortality (shock_pca_chn DD_chn=shock_NTR_f_pca shock_NTR_f) $controls_a $controls_b $controls_d i.region_year poll_emp_pca_chn if age_group==1 & year==2010 [aweight=weight], endog(shock_pca_chn DD_chn) first ffirst savefirst partial(i.region_year) cluster(province)
matrix stat=e(first)
local temp1=stat[15,1]
local temp2=stat[15,2]
outreg2 using "$dir/result/result_age0_ntr.tex", keep(shock_pca_chn DD_chn) dec(3) addstat("Fstat PollExpShock", `temp1', "Fstat ExpShock", `temp2') tex nocons append

ivreg2 d_All_mortality (shock_pca_chn DD_chn=shock_NTR_gap_pca shock_NTR_gap) $controls_a $controls_b $controls_d i.region_year poll_emp_pca_chn if age_group==1 & year==2010 [aweight=weight], endog(shock_pca_chn DD_chn) first ffirst savefirst partial(i.region_year) cluster(province)
matrix stat=e(first)
local temp1=stat[15,1]
local temp2=stat[15,2]
outreg2 using "$dir/result/result_age0_ntr.tex", keep(shock_pca_chn DD_chn) dec(3) addstat("Fstat PollExpShock", `temp1', "Fstat ExpShock", `temp2') tex nocons append

** first stage 
regress shock_pca_chn shock_pca_f_chn DD_f_chn $controls_a $controls_b $controls_d i.region_year if age_group==1 & year==2010 [aweight=weight], cluster(province)
est store r1
regress shock_pca_chn shock_NTR_f_pca shock_NTR_f $controls_a $controls_b $controls_d i.region_year if age_group==1 & year==2010 [aweight=weight], cluster(province)
est store r2
regress shock_pca_chn shock_NTR_gap_pca shock_NTR_gap $controls_a $controls_b $controls_d i.region_year if age_group==1 & year==2010 [aweight=weight], cluster(province)
est store r3
outreg2 [r1 r2 r3] using "$dir/result/result_age0_ntr_FS1.tex", keep(shock_pca_f_chn DD_f_chn shock_NTR_f_pca shock_NTR_f shock_NTR_gap_pca shock_NTR_gap) dec(3) tex nocons replace

regress DD_chn shock_pca_f_chn DD_f_chn $controls_a $controls_b $controls_d i.region_year if age_group==1 & year==2010 [aweight=weight], cluster(province)
est store r4
regress DD_chn shock_NTR_f_pca shock_NTR_f $controls_a $controls_b $controls_d i.region_year if age_group==1 & year==2010 [aweight=weight], cluster(province)
est store r5
regress DD_chn shock_NTR_gap_pca shock_NTR_gap $controls_a $controls_b $controls_d i.region_year if age_group==1 & year==2010 [aweight=weight], cluster(province)
est store r6
outreg2 [r4 r5 r6] using "$dir/result/result_age0_ntr_FS2.tex", keep(shock_pca_f_chn DD_f_chn shock_NTR_f_pca shock_NTR_f shock_NTR_gap_pca shock_NTR_gap) dec(3) tex nocons replace
