clear
global dir "/Users/bingjingli/Dropbox/China_export_environment/replication package"

use "$dir/workfile.dta",clear

****************************

global controls_a "lag_GDP_cap lag_All_mortality_overall lag_share_agriculture lag_pop_density capital"
global controls_b "d_highschool d_midschool d_sex_ratio d_Beds_pop d_share_agriculture i.dist_g"
global controls_d "lag_d_All_mortality lag_d_All_mortality2"
global controls_e "lag_share_emp_ind_l lag_share_emp_ind_m lag_share_emp_ind_h"

set matsize 5000

egen region_year=group(region year)
egen province_year=group(province year)
destring prefect_adj, replace

gen year2010=cond(year==2010,1,0)
gen year2000=cond(year==2000,1,0)

/* pollution shock: without normalization */

gen shock_pt_tot=shock_pt_chn*lag_prefect_emp*100/1000000
gen shock_so2_tot=shock_so2_chn*lag_prefect_emp*100/1000000
gen shock_no2_tot=shock_no2_chn*lag_prefect_emp*100/1000000
pca shock_pt_tot shock_so2_tot shock_no2_tot, com(1)
predict shock_pca_tot 
gen shock_pt_f_tot=shock_pt_f_chn*lag_prefect_emp*100/1000000
gen shock_so2_f_tot=shock_so2_f_chn*lag_prefect_emp*100/1000000
gen shock_no2_f_tot=shock_no2_f_chn*lag_prefect_emp*100/1000000
pca shock_pt_f_tot shock_so2_f_tot shock_no2_f_tot, com(1)
predict shock_pca_f_tot
gen DD_chn_tot=DD_chn*lag_prefect_emp*100/1000000
gen DD_f_chn_tot=DD_f_chn*lag_prefect_emp*100/1000000

/* neighboring shock */

gen DD_chn_nn=DD_chn_n+DD_chn
gen DD_f_chn_nn=DD_f_chn_n+DD_f_chn
local pollutant "so2 no2 pt"
foreach p of local pollutant {
	gen shock_`p'_chn_nn=shock_`p'_chn_w+shock_`p'_chn
	gen shock_`p'_f_chn_nn=shock_`p'_f_chn_w+shock_`p'_f_chn
	}
pca shock_pt_chn_nn shock_so2_chn_nn shock_no2_chn_nn, com(1)
predict shock_pca_chn_nn	
pca shock_pt_f_chn_nn shock_so2_f_chn_nn shock_no2_f_chn_nn, com(1)
predict shock_pca_f_chn_nn

**************************************

ivreg2 d_pm25 (shock_pca_chn DD_chn=shock_pca_f_chn DD_f_chn) $controls_a $controls_b $controls_d poll_emp_pt_chn i.province_year if age_group==1 & year==2010 [aweight=lag_All_birth], ///
partial(i.province_year) cluster(province)
outreg2 using "mortality_rate/results/result_pm25_robust.tex", keep(shock_pca_chn DD_chn) dec(3) tex nocons replace

ivreg2 d_pm25 (shock_pca_chn DD_chn=shock_pca_f_chn DD_f_chn) $controls_a $controls_b $controls_d poll_emp_pt_chn i.region_year if age_group==1 & year==2010, ///
partial(i.region_year) cluster(province)
outreg2 using "mortality_rate/results/result_pm25_robust.tex", keep(shock_pca_chn DD_chn) dec(3) tex nocons append

ivreg2 d_pm25 (shock_pca_tot DD_chn=shock_pca_f_tot DD_f_chn) $controls_a $controls_b $controls_d poll_emp_pt_chn i.region_year if age_group==1 & year==2010 [aweight=lag_All_birth], ///
partial(i.region_year) cluster(province)
outreg2 using "mortality_rate/results/result_pm25_robust.tex", keep(shock_pca_tot DD_chn) dec(3) tex nocons append

ivreg2 d_pm25 (shock_pca_chn shock_pca_chn_w DD_chn DD_chn_n=shock_pca_f_chn shock_pca_f_chn_w DD_f_chn DD_f_chn_n) $controls_a $controls_b $controls_d poll_emp_pt_chn i.region_year if age_group==1 & year==2010 [aweight=lag_All_birth], ///
partial(i.region_year) cluster(province)
outreg2 using "mortality_rate/results/result_pm25_robust.tex", keep(shock_pca_chn shock_pca_chn_w DD_chn DD_chn_n) dec(3) tex nocons append 

ivreg2 d_pm25 (shock_pca_chn_nn DD_chn_nn=shock_pca_f_chn_nn DD_f_chn_nn) $controls_a $controls_b $controls_d poll_emp_pt_chn i.region_year if age_group==1 & year==2010 [aweight=lag_All_birth], ///
partial(i.region_year) cluster(province)
outreg2 using "mortality_rate/results/result_pm25_robust.tex", keep(shock_pca_chn_nn DD_chn_nn) dec(3) tex nocons append

ivreg2 d_pm25 (shock_pca_io DD_io=shock_pca_f_io DD_f_io) $controls_a $controls_b $controls_d poll_emp_pt_chn i.region_year if age_group==1 & year==2010 [aweight=lag_All_birth], ///
partial(i.region_year) cluster(province)
outreg2 using "mortality_rate/results/result_pm25_robust.tex", keep(shock_pca_io DD_io) dec(3) tex nocons append

ivreg2 d_pm25 (shock_pca_cus export_cus=shock_pca_f_chn DD_f_chn) $controls_a $controls_b $controls_d poll_emp_pt_chn i.region_year if age_group==1 & year==2010 [aweight=lag_All_birth], ///
partial(i.region_year) cluster(province)
outreg2 using "mortality_rate/results/result_pm25_robust.tex", keep(shock_pca_cus export_cus) dec(3) tex nocons append

ivreg2 d_pm25 (shock_pca_chn DD_es_chn=shock_pca_f_chn DD_es_f_chn) $controls_a $controls_b $controls_d poll_emp_ex_pt_chn i.region_year if age_group==1 & year==2010 [aweight=lag_All_birth], ///
partial(i.region_year) cluster(province)
outreg2 using "mortality_rate/results/result_pm25_robust.tex", keep(shock_pca_chn DD_es_chn) dec(3) tex nocons append

ivreg2 d_pm25 (DD_air_a_h DD_air_a_l=DD_air_a_h_f DD_air_a_l_f) $controls_a $controls_b $controls_d poll_emp_ex_pt_chn i.region_year if age_group==1 & year==2010 [aweight=lag_All_birth], ///
partial(i.region_year) cluster(province)
outreg2 using "mortality_rate/results/result_pm25_robust.tex", keep(DD_air_a_h DD_air_a_l) dec(3) tex nocons append

ivreg2 d_pm25 (shock_pca_ms output_ms=shock_pca_f_chn DD_f_chn) $controls_a $controls_b $controls_d poll_emp_pt_chn i.region_year if age_group==1 & year==2010 [aweight=lag_All_birth], ///
partial(i.region_year) cluster(province)
outreg2 using "mortality_rate/results/result_pm25_robust.tex", keep(shock_pca_ms output_ms) dec(3) tex nocons append

ivreg2 d_pm25 (shock_pca_chn DD_chn=shock_pca_f_chn DD_f_chn) d_output $controls_a $controls_b $controls_d poll_emp_pt_chn i.region_year if age_group==1 [aweight=lag_All_birth], ///
partial(i.region_year) cluster(province)
outreg2 using "mortality_rate/results/result_pm25_robust_b.tex", keep(shock_pca_chn DD_chn d_output) dec(3) tex nocons replace

ivreg2 d_pm25 (shock_pca_chn DD_chn=shock_pca_f_chn DD_f_chn) shock_imp_pca_chn DD_imp_chn $controls_a $controls_b $controls_d poll_emp_pt_chn i.region_year if age_group==1 [aweight=lag_All_birth], ///
partial(i.region_year) cluster(province)
outreg2 using "mortality_rate/results/result_pm25_robust_b.tex", keep(shock_pca_chn DD_chn shock_imp_pca_chn) dec(3) tex nocons append

ivreg2 d_pm25 (shock_pca_chn DD_chn shock_hs=shock_pca_f_chn DD_f_chn shock_hs_f) $controls_a $controls_b $controls_d poll_emp_pt_chn i.region_year if age_group==1 [aweight=lag_All_birth], ///
partial(i.region_year) cluster(province)
outreg2 using "mortality_rate/results/result_pm25_robust_b.tex", keep(shock_pca_chn DD_chn shock_hs) dec(3) tex nocons append

ivreg2 d_pm25 (shock_pca_chn DD_chn=shock_pca_f_chn DD_f_chn) d_output1 d_output2 $controls_a $controls_b $controls_d poll_emp_pt_chn i.region_year if age_group==1 [aweight=lag_All_birth], ///
partial(i.region_year) cluster(province)
outreg2 using "mortality_rate/results/result_pm25_robust_b.tex", keep(shock_pca_chn DD_chn d_output1 d_output2) dec(3) tex nocons append

ivreg2 d_pm25 (shock_pca_chn DD_chn=shock_pca_f_chn DD_f_chn) TCZ $controls_a $controls_b $controls_d poll_emp_pt_chn i.region_year if age_group==1 [aweight=lag_All_birth], ///
partial(i.region_year) cluster(province)
outreg2 using "mortality_rate/results/result_pm25_robust_b.tex", keep(shock_pca_chn DD_chn TCZ) dec(3) tex nocons append






