
clear
global dir "/Users/bingjingli/Dropbox/China_export_environment/replication package"

***************
/* prepare data */

use "$dir/workfile.dta",clear

keep prefect_adj year
keep if year==2000|year==2010
replace year=year-10
duplicates drop prefect_adj year, force
gen csic_adj=999
gen share_emp_ind=0

save "$dir/temp4.dta", replace

***************
/* exposure to different industries */

use "$dir/employment_weight.dta", clear

keep prefect_adj csic_adj share_emp_ind_1990 share_emp_ind_2000 ind_emp_1990 ind_emp_2000 prefecture_emp_1990 prefecture_emp_2000

reshape long share_emp_ind_ ind_emp_ prefecture_emp_, i(prefect_adj csic_adj) j(year)

rename share_emp_ind_ share_emp_ind
rename ind_emp_ ind_emp
rename prefecture_emp_ prefecture_emp

sort prefect_adj csic_adj year

append using "$dir/temp4.dta"

save "$dir/temp1.dta",replace

***************
/* industry pollution intensity */

use "$dir/intensity_ipp_csic3d.dta",clear

keep csic_adj lb_so2_t_chn1990 lb_pt_t_chn1990 lb_no2_t_chn1990 lb_so2_t_chn2000 lb_pt_t_chn2000 lb_no2_t_chn2000

reshape long lb_so2_t_chn lb_pt_t_chn lb_no2_t_chn, i(csic_adj) j(year)

save "$dir/temp2.dta",replace

***************
/* prefecture-level characteristics */

use "$dir/workfile.dta",clear

keep if age_group==1
keep if year==2000|year==2010
replace year=year-10

rename lag_All_mortality_overall lag_All_mortality_all

global controls_a "lag_GDP_cap lag_All_mortality_all lag_share_agriculture lag_pop_density"
global controls_b "d_highschool d_midschool d_sex_ratio d_Beds_pop d_share_agriculture capital i.dist_g#i.year"
global controls_d "lag_d_All_mortality lag_d_All_mortality2"
global controls_all "$controls_a $controls_b $controls_d poll_emp_pca_chn"

regress d_All_mortality $controls_all i.region#i.year if age_group==1 [aweight=weight]
predict d_All_mortality_res, resid
regress DD_chn $controls_all i.region#i.year if age_group==1 [aweight=weight] 
predict DD_chn_res, resid
regress shock_so2_chn $controls_all i.region#i.year if age_group==1 [aweight=weight]
predict shock_so2_chn_res, resid
regress shock_no2_chn $controls_all i.region#i.year if age_group==1 [aweight=weight]
predict shock_no2_chn_res, resid
regress shock_pt_chn $controls_all i.region#i.year if age_group==1 [aweight=weight]
predict shock_pt_chn_res, resid
regress shock_pca_chn $controls_all i.region#i.year if age_group==1 [aweight=weight]
predict shock_pca_chn_res, resid

keep prefect_adj region year d_All_mortality lag_d_All_mortality lag_GDP_cap lag_All_mortality_all lag_share_agriculture lag_pop_density ///
	d_highschool d_midschool d_sex_ratio d_Beds_pop d_share_agriculture dist_ports poll_emp_pca_chn ///
	d_All_mortality_res DD_chn_res shock_pt_chn_res shock_no2_chn_res shock_so2_chn_res shock_pca_chn_res weight
	
replace lag_pop_density=lag_pop_density/100
replace lag_GDP_cap=log(lag_GDP_cap)
egen region_year=group(region year)

global controls "poll_emp_pca_chn lag_d_All_mortality lag_All_mortality_all lag_pop_density lag_GDP_cap lag_share_agriculture dist_ports d_Beds_pop d_sex_ratio d_highschool d_midschool d_share_agriculture"
global controls_r "poll_emp_pca_chn_r lag_d_All_mortality_r lag_All_mortality_all_r lag_pop_density_r lag_GDP_cap_r lag_share_agriculture_r dist_ports_r d_Beds_pop_r d_sex_ratio_r d_highschool_r d_midschool_r d_share_agriculture_r"

foreach var of global controls {
	regress `var' i.region_year [aweight=weight] 
	predict `var'_r, resid
	}
	
save "$dir/temp3.dta",replace

***************
/* industry-level shocks and outcomes */

use "$dir/China_export_csic_fitted_wide.dta", clear

keep csic_adj export_tariff1992 export_f1992 export_tariff2000 export_f2000 export_tariff2010 export_f2010

gen d_export_f1990=export_f2000-export_f1992
gen d_export_f2000=export_f2010-export_f2000
gen d_ln_export_tariff1990=log(1+export_tariff2000/100)-log(1+export_tariff1992/100)
gen d_ln_export_tariff2000=log(1+export_tariff2010/100)-log(1+export_tariff2000/100)

keep csic_adj d_export_f* d_ln_export_tariff*
reshape long d_export_f d_ln_export_tariff, i(csic_adj) j(year)

merge 1:1 csic_adj year using "$dir/temp2.dta"
drop if _merge==2
drop _merge

local pollutant "so2 pt no2"
foreach p of local pollutant {
	gen d_export_`p'=d_export_f*lb_`p'_t_chn
	}

set obs 297
set obs 298
replace csic_adj=999 in 297
replace csic_adj=999 in 298
replace year=1990 in 297
replace year=2000 in 298

foreach var of varlist d_export_f-d_export_no2 {
	replace `var'=0 if `var'==.
	}

merge 1:m csic_adj year using "$dir/temp1.dta"
drop if _merge==2
drop _merge

replace share_emp_ind=0 if share_emp_ind==.

sort prefect_adj year csic_adj
bysort prefect_adj year: egen temp=sum(share_emp_ind)
replace share_emp_ind=1-temp if csic_adj==999
drop temp

bysort year: egen temp1=sum(prefecture_emp)
bysort prefect_adj year: egen temp2=sum(ind_emp)
replace ind_emp=temp1-temp2 if csic_adj==999
drop temp1 temp2

gen d_export_f_pw=d_export_f/(ind_emp*100)
foreach p of local pollutant {
	gen d_export_`p'_pw=d_export_`p'/(ind_emp*100)
	}

merge m:1 prefect_adj year using "$dir/temp3.dta"
drop if _merge==2
drop _merge

*drop if substr(prefect_adj,1,2)=="54" & year==1990
replace share_emp_ind=share_emp_ind*weight
bysort csic_adj year: egen avg_share_emp_ind=mean(share_emp_ind)
bysort csic_adj year: egen sum_share_emp_ind=sum(share_emp_ind)
gen w_share_emp_ind=share_emp_ind/sum_share_emp_ind if year==2000
replace w_share_emp_ind=share_emp_ind/sum_share_emp_ind if year==1990

foreach var of global controls {
	replace `var'=`var'*w_share_emp_ind
	}
	
foreach var of global controls_r {
	replace `var'=`var'*w_share_emp_ind
	}
	
foreach var of varlist d_All_mortality_res DD_chn_res shock_pt_chn_res shock_so2_chn_res shock_no2_chn_res shock_pca_chn_res {
	replace `var'=`var'*w_share_emp_ind
	}	

collapse (mean) d_ln_export_tariff d_export_f_pw-d_export_no2_pw avg_share_emp_ind ///
	(sum) $controls $controls_r d_All_mortality_res DD_chn_res shock_pt_chn_res shock_so2_chn_res shock_no2_chn_res shock_pca_chn_res, by(csic_adj year)

save "$dir/temp.dta",replace

***************
***************
/* Table A.9 */

use "$dir/temp.dta",clear

pca d_export_so2_pw d_export_pt_pw d_export_no2_pw [aweight=avg_share_emp_ind], com(1)
predict d_export_pca_pw

pwcorr(d_export_pca_pw d_export_f_pw) [aweight=avg_share_emp_ind]

gen csic_2d=int(csic_adj/10)
	
local counter=1
matrix summary=J(12,4,0)  
foreach var of global controls_r {
	
	regress `var' d_export_pt_pw  d_export_f_pw  i.year [aweight=avg_share_emp_ind], cluster(csic_adj)
	matrix summary[`counter',1]=_b[d_export_pt_pw]*100
	matrix summary[`counter',2]=_b[d_export_pt_pw]/_se[d_export_pt_pw]
	matrix summary[`counter',3]=_b[d_export_f_pw]*100
	matrix summary[`counter',4]=_b[d_export_f_pw]/_se[d_export_f_pw]	
	
	/*
	regress `var' d_export_f_pw d_export_pca_pw i.year [aweight=avg_share_emp_ind], cluster(csic_adj)
	matrix summary[`counter',3]=_b[d_export_f_pw]
	matrix summary[`counter',4]=_b[d_export_f_pw]/_se[d_export_f_pw]
	*/
	
	local counter=`counter'+1
	}
matrix list summary

outtable using "$dir/result/Table_balance",mat(summary) replace center f(%9.3f)


***************
***************	
/* Table A.10 */

use "$dir/workfile.dta",clear

keep if age_group==1
keep if year==2000|year==2010

rename lag_All_mortality_overall lag_All_mortality_all

ivreg2 d_All_mortality (shock_pt_chn DD_chn=DD_f_chn shock_pt_f_chn) $controls_all i.region#i.year [aweight=weight], endog(shock_pt_chn DD_chn) first ffirst savefirst cluster(province)
matrix stat=e(first)
local temp1=stat[15,1]
local temp2=stat[15,2]
outreg2 using "$dir/result/result_age0_BHJ.tex", keep(shock_pt_chn DD_chn) addstat("Fstat PollExpShock", `temp1',"Fstat ExpShock", `temp2') dec(3) tex replace


use "$dir/temp.dta",clear

ivreg2 d_All_mortality_res (shock_pt_chn_res DD_chn_res=d_export_pt_pw d_export_f_pw) [aweight=avg_share_emp_ind], endog(shock_pt_chn_res DD_chn_res) first ffirst savefirst cluster(csic_adj)
matrix stat=e(first)
local temp1=stat[15,1]
local temp2=stat[15,2]
outreg2 using "$dir/result/result_age0_BHJ.tex", keep(shock_pt_chn_res DD_chn_res) addstat("Fstat PollExpShock", `temp1',"Fstat ExpShock", `temp2') dec(3) tex append


***************
erase "$dir/temp1.dta"
erase "$dir/temp2.dta"
erase "$dir/temp3.dta"
erase "$dir/temp4.dta"
erase "$dir/temp.dta"
