
clear
global dir "/Users/bingjingli/Dropbox/China_export_environment/replication package"

***********************
use "$dir/employment_weight.dta", clear

merge m:1 csic_adj using "$dir/China_export_csic_wide.dta"
keep if _merge==3
drop _merge

keep if prefect_adj=="1100"

merge 1:1 csic_adj using "$dir/intensity_ipp_csic3d.dta"
keep if _merge==3
drop _merge

keep csic_adj ind_emp_1990 ind_emp_2000 export1992 export2000 export2010 lb_so2_t_chn1990-lb_no2_t_chn2000
gen d_export2000=(export2000-export1992)/(ind_emp_1990*100)
gen d_export2010=(export2010-export1992)/(ind_emp_2000*100)

xtile group_shock2000=d_export2000, nq(3)
xtile group_shock2010=d_export2010, nq(3)
egen temp1=rank(lb_pt_t_chn1990)
egen temp2=rank(lb_so2_t_chn1990)
gen temp=temp1+temp2
xtile group_poll2000=temp, nq(2)
drop temp temp1 temp2
egen temp1=rank(lb_pt_t_chn2000)
egen temp2=rank(lb_so2_t_chn2000)
gen temp=temp1+temp2
xtile group_poll2010=temp, nq(2)
drop temp temp1 temp2

egen group2000=group(group_shock2000 group_poll2000)
egen group2010=group(group_shock2010 group_poll2010)

keep csic_adj group2000 group2010

merge 1:m csic_adj using "$dir/employment_weight.dta"
keep if _merge==3
drop _merge

preserve
collapse (sum) share_emp_ind_2000, by(prefect_adj group2010)

*keep if group2010==1|group2010==2 /*placebo*/
keep if group2010==5|group2010==6

bysort prefect_adj: gen share_emp_clean_2000=share_emp_ind_2000[_n-1]
gen share_emp_dirty_2000=share_emp_ind_2000
*keep if group2010==2 /*placebo*/
keep if group2010==6
keep prefect_adj share_emp_clean_* share_emp_dirty_*

save "$dir/temp.dta",replace
restore

preserve
collapse (sum) share_emp_ind_1990, by(prefect_adj group2000)

*keep if group2000==1|group2000==2 /*for placebo*/
keep if group2000==4|group2000==6

bysort prefect_adj: gen share_emp_clean_1990=share_emp_ind_1990[_n-1]
gen share_emp_dirty_1990=share_emp_ind_1990
*keep if group2000==2 /*for placebo*/
keep if group2000==6
keep prefect_adj share_emp_clean_* share_emp_dirty_*

merge 1:1 prefect_adj using "$dir/temp.dta"
drop _merge

save "$dir/temp.dta",replace
restore

********************************************************************************************

use "$dir/workfile.dta", clear

merge m:1 prefect_adj using "$dir/temp.dta"
keep if _merge==3
drop _merge

keep if year==2010|year==2000
keep if age_group==1

gen r_share2000=(share_emp_dirty_2000)/(share_emp_clean_2000+share_emp_dirty_2000)
*replace r_share2000=0.5 if r_share2000==.
gen r_share1990=(share_emp_dirty_1990)/(share_emp_clean_1990+share_emp_dirty_1990)
*replace r_share1990=0.5 if r_share1990==.
gen r_share=r_share1990
replace r_share=r_share2000 if year==2010

cap drop temp1 temp2
regress d_All_mortality lag_All_mortality r_share2000 if year==2010
avplot r_share2000
local coef=int(_b[r_share2000]*1000)/1000
local se=int(_se[r_share2000]*1000)/1000
regress d_All_mortality lag_All_mortality if year==2010  
predict temp1, resid
regress r_share2000 lag_All_mortality if year==2010 
predict temp2, resid

twoway (scatter temp1 temp2 if year==2010 & temp1<15 & temp1>-15, msize(small)) (function y=`coef'*x, range(-0.5 0.75)), ///
text(-12 0.5 "Coef: `coef'" "         (`se')") ///
xtitle("Dirty/(Clean+Dirty) employment ratio for high export growth industries") ytitle("{&Delta} IMR")  ///
ylabel(-15(5)15) xlabel(-0.5(0.25)0.75) legend(off) ///
graphregion(color(white)) name(p1,replace)

graph export "$dir/result/graph_correlation_2010.eps",replace

/*
twoway (scatter temp1 temp2 if year==2010 & temp1<15 & temp1>-15, msize(small)) (function y=`coef'*x, range(-0.5 0.5)), ///
text(-12 0.3 "Coef: `coef'" "         (`se')") ///
xtitle("Dirty/(Clean+Dirty) employment ratio for low export growth industries") ytitle("{&Delta} IMR")  ///
ylabel(-15(5)15) xlabel(-0.5(0.25)0.5) legend(off) ///
graphregion(color(white)) name(p1,replace)

graph export "$dir/result/graph_correlation_2010_placebo.eps",replace
*/

erase "$dir/temp.dta"


